/* Overrides for bootstrap classes */

/* overrides primary button colors to match theme */

.btn-primary {
    .buttonBackground(@themeColor, @themeSecondary);
    .buttonLinkColor(@themeColor);
    &.active {
      .buttonLinkColor(@themeColor);
    }
}

.btn-primary:hover {
    .buttonLinkHoverColor(@themeColor);
}

.btn-success {
    .buttonBackground(lighten(#52b42b, 10%), #52b42b);
}

/* stacked nav for content pages in theme 1 and 2 */

.nav-stacked {
    li {
        a:hover {
            background-color: fadeout(@themeColor, 95%);
        }
    }
    .active {
        a {
            background-color: fadeout(@themeColor, 95%);
        }
        a:hover {
            background-color: fadeout(@themeColor, 95%);
        }
    }
}


/* other overrides */

.form-actions {
    background: none;
    border: 0;
}

.controls {
    ul {
        list-style: none;
        margin-left: 0px;
    }
}

