{% extends "socialschools_cms/theme_3_base.html" %}
{% load staticfiles %}
{% load sekizai_tags %}
{% load menu_tags %}
{% load i18n %}
{% load compress %}
{% load socialschools_tags %}
{% load cms_tags %}

{% block wrapper %}
    <div class="carousel-theme-3">
        {% placeholder carousel %}
        <div class="carousel-theme-3-mask">
        </div>
        <div class="container carousel-theme-3-tagline">
            {% placeholder carousel_tagline %}
        </div>
    </div>
    <div class="container">
        <div class="row pillars-theme-3">
            <div class="span12">
                {% placeholder pillars %}
            </div>
        </div>
        <div class="row-fluid">
            <div class="span8">
                {% include "socialschools_cms/includes/news.html" %}
            </div>
            <div class="span4">
                {% placeholder banners %}
            </div>
        </div>
    </div>
{% endblock %}
